==> gerbil-0.15.1.tgz: gerbil/lib/static/std__net__socket__base.scm <==
(declare (block) (standard-bindings) (extended-bindings))
(begin
  (define std/net/socket/base#current-socket-server (make-parameter '#f))
  (define std/net/socket/base#!socket::t
    (make-struct-type
     'std/net/socket/base#!socket::t
     '#f
     '4
     '!socket
     '((final: . #t))
     '#f
     '(e wait-in wait-out close)))
  (define std/net/socket/base#!socket?
    (make-struct-predicate std/net/socket/base#!socket::t))
  (define std/net/socket/base#make-!socket
    (lambda _$args147438_
      (apply make-struct-instance
             std/net/socket/base#!socket::t
             _$args147438_)))
  (define std/net/socket/base#!socket-e
    (make-struct-field-accessor std/net/socket/base#!socket::t '0))
  (define std/net/socket/base#!socket-wait-in
    (make-struct-field-accessor std/net/socket/base#!socket::t '1))
  (define std/net/socket/base#!socket-wait-out
    (make-struct-field-accessor std/net/socket/base#!socket::t '2))
  (define std/net/socket/base#!socket-close
    (make-struct-field-accessor std/net/socket/base#!socket::t '3))
  (define std/net/socket/base#!socket-e-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '0))
  (define std/net/socket/base#!socket-wait-in-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '1))
  (define std/net/socket/base#!socket-wait-out-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '2))
  (define std/net/socket/base#!socket-close-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '3))
  (define std/net/socket/base#!io-state::t
    (make-struct-type
     'std/net/socket/base#!io-state::t
     '#f
     '3
     '!io-state
     '((final: . #t))
     ':init!
     '(e mx cv)))
  (define std/net/socket/base#!io-state?
    (make-struct-predicate std/net/socket/base#!io-state::t))
  (define std/net/socket/base#make-!io-state
    (lambda _$args147435_
      (apply make-struct-instance
             std/net/socket/base#!io-state::t
             _$args147435_)))
  (define std/net/socket/base#!io-state-e
    (make-struct-field-accessor std/net/socket/base#!io-state::t '0))
  (define std/net/socket/base#!io-state-mx
    (make-struct-field-accessor std/net/socket/base#!io-state::t '1))
  (define std/net/socket/base#!io-state-cv
    (make-struct-field-accessor std/net/socket/base#!io-state::t '2))
  (define std/net/socket/base#!io-state-e-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '0))
  (define std/net/socket/base#!io-state-mx-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '1))
  (define std/net/socket/base#!io-state-cv-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '2))
  (define std/net/socket/base#!socket-state::t
    (make-struct-type
     'std/net/socket/base#!socket-state::t
     '#f
     '3
     '!socket-state
     '((final: . #t))
     '#f
     '(e io-in io-out)))
  (define std/net/socket/base#!socket-state?
    (make-struct-predicate std/net/socket/base#!socket-state::t))
  (define std/net/socket/base#make-!socket-state
    (lambda _$args147432_
      (apply make-struct-instance
             std/net/socket/base#!socket-state::t
             _$args147432_)))
  (define std/net/socket/base#!socket-state-e
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '0))
  (define std/net/socket/base#!socket-state-io-in
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '1))
  (define std/net/socket/base#!socket-state-io-out
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '2))
  (define std/net/socket/base#!socket-state-e-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '0))
  (define std/net/socket/base#!socket-state-io-in-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '1))
  (define std/net/socket/base#!socket-state-io-out-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '2))
  (define std/net/socket/base#socket-server::proto
    (##structure
     std/actor/proto#!protocol::t
     'std/net/socket/base#socket-server
     '()
     (hash-copy std/actor/xdr#+xdr-default-type-registry+)))
  (define std/net/socket/base#socket-server.shutdown!::t
    (make-struct-type
     'std/net/socket/base#socket-server.shutdown!::t
     '#f
     '0
     'socket-server.shutdown!
     '((final: . #t))
     '#f
     '()))
  (define std/net/socket/base#socket-server.shutdown!?
    (make-struct-predicate std/net/socket/base#socket-server.shutdown!::t))
  (define std/net/socket/base#make-socket-server.shutdown!
    (lambda _$args147429_
      (apply make-struct-instance
             std/net/socket/base#socket-server.shutdown!::t
             _$args147429_)))
  (define std/net/socket/base#xdr-socket-server.shutdown!-read
    (lambda (_buffer147427_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.shutdown!::t
       _buffer147427_)))
  (define std/net/socket/base#xdr-socket-server.shutdown!-write
    (lambda (_obj147424_ _buffer147425_)
      (std/actor/xdr#xdr-write-struct _obj147424_ _buffer147425_)))
  (define std/net/socket/base#socket-server.shutdown!::xdr
    (##structure
     std/actor/xdr#XDR::t
     std/net/socket/base#xdr-socket-server.shutdown!-read
     std/net/socket/base#xdr-socket-server.shutdown!-write))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.shutdown!::t
   std/net/socket/base#socket-server.shutdown!::xdr)
  (define std/net/socket/base#socket-server.add::t
    (make-struct-type
     'std/net/socket/base#socket-server.add::t
     '#f
     '1
     'socket-server.add
     '((final: . #t))
     '#f
     '(sock)))
  (define std/net/socket/base#socket-server.add?
    (make-struct-predicate std/net/socket/base#socket-server.add::t))
  (define std/net/socket/base#make-socket-server.add
    (lambda _$args147421_
      (apply make-struct-instance
             std/net/socket/base#socket-server.add::t
             _$args147421_)))
  (define std/net/socket/base#socket-server.add-sock
    (make-struct-field-accessor std/net/socket/base#socket-server.add::t '0))
  (define std/net/socket/base#socket-server.add-sock-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.add::t '0))
  (define std/net/socket/base#xdr-socket-server.add-read
    (lambda (_buffer147419_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.add::t
       _buffer147419_)))
  (define std/net/socket/base#xdr-socket-server.add-write
    (lambda (_obj147416_ _buffer147417_)
      (std/actor/xdr#xdr-write-struct _obj147416_ _buffer147417_)))
  (define std/net/socket/base#socket-server.add::xdr
    (##structure
     std/actor/xdr#XDR::t
     std/net/socket/base#xdr-socket-server.add-read
     std/net/socket/base#xdr-socket-server.add-write))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.add::t
   std/net/socket/base#socket-server.add::xdr)
  (define std/net/socket/base#socket-server.poll::t
    (make-struct-type
     'std/net/socket/base#socket-server.poll::t
     '#f
     '0
     'socket-server.poll
     '((final: . #t))
     '#f
     '()))
  (define std/net/socket/base#socket-server.poll?
    (make-struct-predicate std/net/socket/base#socket-server.poll::t))
  (define std/net/socket/base#make-socket-server.poll
    (lambda _$args147413_
      (apply make-struct-instance
             std/net/socket/base#socket-server.poll::t
             _$args147413_)))
  (define std/net/socket/base#xdr-socket-server.poll-read
    (lambda (_buffer147411_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.poll::t
       _buffer147411_)))
  (define std/net/socket/base#xdr-socket-server.poll-write
    (lambda (_obj147408_ _buffer147409_)
      (std/actor/xdr#xdr-write-struct _obj147408_ _buffer147409_)))
  (define std/net/socket/base#socket-server.poll::xdr
    (##structure
     std/actor/xdr#XDR::t
     std/net/socket/base#xdr-socket-server.poll-read
     std/net/socket/base#xdr-socket-server.poll-write))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.poll::t
   std/net/socket/base#socket-server.poll::xdr)
  (define std/net/socket/base#socket-server.close::t
    (make-struct-type
     'std/net/socket/base#socket-server.close::t
     '#f
     '3
     'socket-server.close
     '((final: . #t))
     '#f
     '(ssock dir shutdown)))
  (define std/net/socket/base#socket-server.close?
    (make-struct-predicate std/net/socket/base#socket-server.close::t))
  (define std/net/socket/base#make-socket-server.close
    (lambda _$args147405_
      (apply make-struct-instance
             std/net/socket/base#socket-server.close::t
             _$args147405_)))
  (define std/net/socket/base#socket-server.close-ssock
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '0))
  (define std/net/socket/base#socket-server.close-dir
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '1))
  (define std/net/socket/base#socket-server.close-shutdown
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '2))
  (define std/net/socket/base#socket-server.close-ssock-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '0))
  (define std/net/socket/base#socket-server.close-dir-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '1))
  (define std/net/socket/base#socket-server.close-shutdown-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '2))
  (define std/net/socket/base#xdr-socket-server.close-read
    (lambda (_buffer147403_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.close::t
       _buffer147403_)))
  (define std/net/socket/base#xdr-socket-server.close-write
    (lambda (_obj147398_ _buffer147400_)
      (std/actor/xdr#xdr-write-struct _obj147398_ _buffer147400_)))
  (define std/net/socket/base#socket-server.close::xdr
    (##structure
     std/actor/xdr#XDR::t
     std/net/socket/base#xdr-socket-server.close-read
     std/net/socket/base#xdr-socket-server.close-write))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.close::t
   std/net/socket/base#socket-server.close::xdr)
  (define std/net/socket/base#abs-timeout
    (lambda (_timeo147396_)
      (std/misc/timeout#make-timeout__% _timeo147396_ '#f))))

==> gerbil-0.16.tgz: gerbil/lib/static/std__net__socket__base.scm <==
(declare (block) (standard-bindings) (extended-bindings))
(begin
  (define std/net/socket/base#current-socket-server (make-parameter '#f))
  (define std/net/socket/base#!socket::t
    (make-struct-type
     'std/net/socket/base#!socket::t
     '#f
     '4
     '!socket
     '((final: . #t))
     '#f
     '(e wait-in wait-out close)))
  (define std/net/socket/base#!socket?
    (make-struct-predicate std/net/socket/base#!socket::t))
  (define std/net/socket/base#make-!socket
    (lambda _$args2132_
      (apply make-struct-instance std/net/socket/base#!socket::t _$args2132_)))
  (define std/net/socket/base#!socket-e
    (make-struct-field-accessor std/net/socket/base#!socket::t '0))
  (define std/net/socket/base#!socket-wait-in
    (make-struct-field-accessor std/net/socket/base#!socket::t '1))
  (define std/net/socket/base#!socket-wait-out
    (make-struct-field-accessor std/net/socket/base#!socket::t '2))
  (define std/net/socket/base#!socket-close
    (make-struct-field-accessor std/net/socket/base#!socket::t '3))
  (define std/net/socket/base#!socket-e-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '0))
  (define std/net/socket/base#!socket-wait-in-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '1))
  (define std/net/socket/base#!socket-wait-out-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '2))
  (define std/net/socket/base#!socket-close-set!
    (make-struct-field-mutator std/net/socket/base#!socket::t '3))
  (define std/net/socket/base#!io-state::t
    (make-struct-type
     'std/net/socket/base#!io-state::t
     '#f
     '3
     '!io-state
     '((final: . #t))
     ':init!
     '(e mx cv)))
  (define std/net/socket/base#!io-state?
    (make-struct-predicate std/net/socket/base#!io-state::t))
  (define std/net/socket/base#make-!io-state
    (lambda _$args2129_
      (apply make-struct-instance
             std/net/socket/base#!io-state::t
             _$args2129_)))
  (define std/net/socket/base#!io-state-e
    (make-struct-field-accessor std/net/socket/base#!io-state::t '0))
  (define std/net/socket/base#!io-state-mx
    (make-struct-field-accessor std/net/socket/base#!io-state::t '1))
  (define std/net/socket/base#!io-state-cv
    (make-struct-field-accessor std/net/socket/base#!io-state::t '2))
  (define std/net/socket/base#!io-state-e-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '0))
  (define std/net/socket/base#!io-state-mx-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '1))
  (define std/net/socket/base#!io-state-cv-set!
    (make-struct-field-mutator std/net/socket/base#!io-state::t '2))
  (define std/net/socket/base#!socket-state::t
    (make-struct-type
     'std/net/socket/base#!socket-state::t
     '#f
     '3
     '!socket-state
     '((final: . #t))
     '#f
     '(e io-in io-out)))
  (define std/net/socket/base#!socket-state?
    (make-struct-predicate std/net/socket/base#!socket-state::t))
  (define std/net/socket/base#make-!socket-state
    (lambda _$args2126_
      (apply make-struct-instance
             std/net/socket/base#!socket-state::t
             _$args2126_)))
  (define std/net/socket/base#!socket-state-e
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '0))
  (define std/net/socket/base#!socket-state-io-in
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '1))
  (define std/net/socket/base#!socket-state-io-out
    (make-struct-field-accessor std/net/socket/base#!socket-state::t '2))
  (define std/net/socket/base#!socket-state-e-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '0))
  (define std/net/socket/base#!socket-state-io-in-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '1))
  (define std/net/socket/base#!socket-state-io-out-set!
    (make-struct-field-mutator std/net/socket/base#!socket-state::t '2))
  (define std/net/socket/base#socket-server::proto
    (let ((__tmp7461 (hash-copy std/actor/xdr#+xdr-default-type-registry+)))
      (declare (not safe))
      (##structure
       std/actor/proto#!protocol::t
       'std/net/socket/base#socket-server
       '()
       __tmp7461)))
  (define std/net/socket/base#socket-server.shutdown!::t
    (make-struct-type
     'std/net/socket/base#socket-server.shutdown!::t
     '#f
     '0
     'socket-server.shutdown!
     '((final: . #t))
     '#f
     '()))
  (define std/net/socket/base#socket-server.shutdown!?
    (make-struct-predicate std/net/socket/base#socket-server.shutdown!::t))
  (define std/net/socket/base#make-socket-server.shutdown!
    (lambda _$args2123_
      (apply make-struct-instance
             std/net/socket/base#socket-server.shutdown!::t
             _$args2123_)))
  (define std/net/socket/base#xdr-socket-server.shutdown!-read
    (lambda (_buffer2121_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.shutdown!::t
       _buffer2121_)))
  (define std/net/socket/base#xdr-socket-server.shutdown!-write
    (lambda (_obj2118_ _buffer2119_)
      (std/actor/xdr#xdr-write-struct _obj2118_ _buffer2119_)))
  (define std/net/socket/base#socket-server.shutdown!::xdr
    (let ()
      (declare (not safe))
      (##structure
       std/actor/xdr#XDR::t
       std/net/socket/base#xdr-socket-server.shutdown!-read
       std/net/socket/base#xdr-socket-server.shutdown!-write)))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.shutdown!::t
   std/net/socket/base#socket-server.shutdown!::xdr)
  (define std/net/socket/base#socket-server.add::t
    (make-struct-type
     'std/net/socket/base#socket-server.add::t
     '#f
     '1
     'socket-server.add
     '((final: . #t))
     '#f
     '(sock)))
  (define std/net/socket/base#socket-server.add?
    (make-struct-predicate std/net/socket/base#socket-server.add::t))
  (define std/net/socket/base#make-socket-server.add
    (lambda _$args2115_
      (apply make-struct-instance
             std/net/socket/base#socket-server.add::t
             _$args2115_)))
  (define std/net/socket/base#socket-server.add-sock
    (make-struct-field-accessor std/net/socket/base#socket-server.add::t '0))
  (define std/net/socket/base#socket-server.add-sock-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.add::t '0))
  (define std/net/socket/base#xdr-socket-server.add-read
    (lambda (_buffer2113_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.add::t
       _buffer2113_)))
  (define std/net/socket/base#xdr-socket-server.add-write
    (lambda (_obj2110_ _buffer2111_)
      (std/actor/xdr#xdr-write-struct _obj2110_ _buffer2111_)))
  (define std/net/socket/base#socket-server.add::xdr
    (let ()
      (declare (not safe))
      (##structure
       std/actor/xdr#XDR::t
       std/net/socket/base#xdr-socket-server.add-read
       std/net/socket/base#xdr-socket-server.add-write)))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.add::t
   std/net/socket/base#socket-server.add::xdr)
  (define std/net/socket/base#socket-server.poll::t
    (make-struct-type
     'std/net/socket/base#socket-server.poll::t
     '#f
     '0
     'socket-server.poll
     '((final: . #t))
     '#f
     '()))
  (define std/net/socket/base#socket-server.poll?
    (make-struct-predicate std/net/socket/base#socket-server.poll::t))
  (define std/net/socket/base#make-socket-server.poll
    (lambda _$args2107_
      (apply make-struct-instance
             std/net/socket/base#socket-server.poll::t
             _$args2107_)))
  (define std/net/socket/base#xdr-socket-server.poll-read
    (lambda (_buffer2105_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.poll::t
       _buffer2105_)))
  (define std/net/socket/base#xdr-socket-server.poll-write
    (lambda (_obj2102_ _buffer2103_)
      (std/actor/xdr#xdr-write-struct _obj2102_ _buffer2103_)))
  (define std/net/socket/base#socket-server.poll::xdr
    (let ()
      (declare (not safe))
      (##structure
       std/actor/xdr#XDR::t
       std/net/socket/base#xdr-socket-server.poll-read
       std/net/socket/base#xdr-socket-server.poll-write)))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.poll::t
   std/net/socket/base#socket-server.poll::xdr)
  (define std/net/socket/base#socket-server.close::t
    (make-struct-type
     'std/net/socket/base#socket-server.close::t
     '#f
     '3
     'socket-server.close
     '((final: . #t))
     '#f
     '(ssock dir shutdown)))
  (define std/net/socket/base#socket-server.close?
    (make-struct-predicate std/net/socket/base#socket-server.close::t))
  (define std/net/socket/base#make-socket-server.close
    (lambda _$args2099_
      (apply make-struct-instance
             std/net/socket/base#socket-server.close::t
             _$args2099_)))
  (define std/net/socket/base#socket-server.close-ssock
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '0))
  (define std/net/socket/base#socket-server.close-dir
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '1))
  (define std/net/socket/base#socket-server.close-shutdown
    (make-struct-field-accessor std/net/socket/base#socket-server.close::t '2))
  (define std/net/socket/base#socket-server.close-ssock-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '0))
  (define std/net/socket/base#socket-server.close-dir-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '1))
  (define std/net/socket/base#socket-server.close-shutdown-set!
    (make-struct-field-mutator std/net/socket/base#socket-server.close::t '2))
  (define std/net/socket/base#xdr-socket-server.close-read
    (lambda (_buffer2097_)
      (std/actor/xdr#xdr-read-struct
       std/net/socket/base#socket-server.close::t
       _buffer2097_)))
  (define std/net/socket/base#xdr-socket-server.close-write
    (lambda (_obj2092_ _buffer2094_)
      (std/actor/xdr#xdr-write-struct _obj2092_ _buffer2094_)))
  (define std/net/socket/base#socket-server.close::xdr
    (let ()
      (declare (not safe))
      (##structure
       std/actor/xdr#XDR::t
       std/net/socket/base#xdr-socket-server.close-read
       std/net/socket/base#xdr-socket-server.close-write)))
  (table-set!
   (##direct-structure-ref
    std/net/socket/base#socket-server::proto
    '3
    std/actor/proto#!protocol::t
    '#f)
   'std/net/socket/base#socket-server.close::t
   std/net/socket/base#socket-server.close::xdr)
  (define std/net/socket/base#abs-timeout
    (lambda (_timeo2090_) (std/misc/timeout#make-timeout__% _timeo2090_ '#f))))
